@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11783 2019-11-26 12:19:42Z Lavender $
+# $Id: views.py 11784 2019-11-28 09:39:09Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-11-26 21:19:42 +0900 (週二, 26 十一月 2019) $
-# $Revision: 11783 $ 
+# $Date: 2019-11-28 18:39:09 +0900 (週四, 28 十一月 2019) $
+# $Revision: 11784 $ 
 
 import json
 import logging
@@ -528,12 +528,12 @@ def voucherRemoveViewPost(self, request, *args, **kwargs):
             request, _("No voucher found with id '%s'") % voucher_id)
     else:
         request.basket.vouchers.remove(voucher)
-        if voucher.code.startswith("BONUS"):
+        self.remove_signal.send(
+                sender=self, basket=request.basket, voucher=voucher)
+        if re.match(BONUS_VOUCHER_CODE, voucher.code):
             messages.info(
                 request, _("Bouns discount removed from basket"))
         else:
-            self.remove_signal.send(
-                sender=self, basket=request.basket, voucher=voucher)
             messages.info(
                 request, _("Voucher '%s' removed from basket") % voucher.code)
 
@@ -616,6 +616,8 @@ def useBonus(request):
             'end_datetime': datetime.datetime(2099, 12, 31), # FIXME
         }
     )
+    voucher.num_basket_additions += 1
+    voucher.save()
     voucher.offers.add(offer)
     
     # add voucher
